#!/bin/sh
#############################################################################
#                                                                           #
# Short version of mww3_test_03, with files prepared indirectory.           #
#                                                                           #
#                                              Hendrik Tolman, Jan. 2013    #
#                                                                           #
#    Copyright 2013 National Weather Service (NWS),                         #
#       National Oceanic and Atmospheric Administration.  All rights        #
#       reserved.  WAVEWATCH III is a trademark of the NWS.                 #
#       No unauthorized use without permission.                             #
#                                                                           #
#############################################################################

  rm -f *.out
  rm -f *.ww3
  rm -f ww3.*

  echo ' ' ; echo ' '
  echo '                  ======> TEST RUN WAVEWATCH III <====== '
  echo '                    ==================================   '
  echo '                               multi-grid test 03i (prep)'
  echo ' '

# 1. Grid pre-processor -----------------------------------------------------

  echo ' '
  echo '+--------------------+'
  echo '|  Grid preprocessor |'
  echo '+--------------------+'
  echo ' ' 

  for grid in low0 low1 low2 low3 hgh0 hgh1 hgh2 hgh3 point
  do
    ln -s ww3_grid.$grid ww3_grid.inp
    echo "   Screen ouput routed to ww3_grid.$grid.out"
    ww3_grid > ww3_grid.$grid.out
    mv mod_def.ww3 mod_def.$grid
    rm -f ww3_grid.inp
  done

# 2. Initial conditions -----------------------------------------------------

  echo ' '
  echo '+--------------------+'
  echo '| Initial conditions |'
  echo '+--------------------+'
  echo ' '

  for grid in low0 low1 low2 low3 hgh0 hgh1 hgh2 hgh3
  do
    ln -s mod_def.$grid mod_def.ww3
    echo "   Screen ouput routed to ww3_strt.$grid.out"
    ww3_strt > ww3_strt.$grid.out
    mv restart.ww3 restart.$grid
    rm -f mod_def.ww3
  done

# 3. Running the model ------------------------------------------------------

  echo ' '
  echo '+--------------------+'
  echo '|   Run the model    |'
  echo '+--------------------+'
  echo ' '

  mpirun -np 12 ww3_multi

# 4. prepare graphics -------------------------------------------------------

  echo ' '
  echo '+--------------------+'
  echo '|    Field output    |'
  echo '+--------------------+'
  echo ' '

  for file in out_grd.*
  do
    mod=`echo $file | sed 's/\./ /g' | awk '{ print $2}'`

    ln -s mod_def.$mod mod_def.ww3
    ln -s out_grd.$mod out_grd.ww3
    echo "   Screen ouput routed to gx_outf.$mod.out"
    gx_outf > gx_outf.$mod.out
    rm -f mod_def.ww3 out_grd.ww3

    echo "      ww3.ctl routed to $mod.ctl"
    sed -e "s/ww3\.grads/ww3\.$mod/g" \
        -e "s/0\.25/2\.50/g" ww3.ctl > $mod.ctl
    rm -f ww3.ctl
    echo "      ww3.grads routed to ww3.$mod"
    mv ww3.grads ww3.$mod

  done

# 5. End, cleaning up -------------------------------------------------------

# rm -f *.out
# rm -f mod_def.*
# rm -f restart.*
# rm -f restart*.*
# rm -f out_pnt.*
# rm -f out_grd.*

  echo ' ' ; echo ' '
  echo '                  ======>  END OF WAVEWATCH III  <====== '
  echo '                    ==================================   '
  echo ' '

# End of run_it.sh ----------------------------------------------------------
